Honda EU2000i Generator - CARB Compliant - Honda 659820 - Portable Generators - Camping World
Description: Quiet, lightweight Honda Portable Generators deliver clean, reliable power for camping, tailgating or a home power outage.
Keywords: american honda 100993, Honda EU2000i Generator - CARB Compliant, Honda, Honda Generator, Portable Generator, Honda Generators, Portable Generators, Portable Power, Generators, EU2000, EU1000, EU3000, Honda Power Equipment, Generator, Kipor, power, equipment, portable, eu, carb, complaint, california, 2000, RV, Motorhome, Camper, Travel Trailer, Recreational Vehicles, Trailers, Parts, Supplies, Fifth-Wheel, RVing, 5th Wheels

Sign In
Are you a
Member?
Enter your Good Sam Club info
Not a Good Sam Club Member? Join Today
Choose Your Store
Help
FAQ
Order Status Contact Us
1-888-626-7576
Call: 1-888-626-7576
USA
Canada
New Products | Clearance | Internet Specials | Current Ads | Stores | Order Status

- Shop Our Departments
- RVs For Sale
- RV Services
- SALE

0

- Appliances, A/C's & Heaters
- Awnings, Canopies & Shade
- Bikes, Bike Racks & Carriers
- Directories & Memberships
- Camping & Tailgating
- Chairs, Recliners & Patio Mats
- Covers & Storage
- Generators & Electrical
- Electronics, GPS & Satellites
- Grills & Picnic
- Hardware, Roof Vents & Fans
- Outdoor Living
- Indoor Living
- Pet, Training & Feeders
- Sewer, Fresh Water & Cleaners
- Towing, Levels & Chocks

Shop More Appliances, A/C's & Heaters

- Air Conditioners
- Dish Washing
- Portable Heaters & Furnaces
- Small Appliances
- Refrigerators
- Washers & Dryers
- Vacuums and Steam Mops

View All Appliances, A/C's & Heaters Products

Shop Our Top Brands

- Dometic
- Norcold
- Atwood Mobile
- Camco
- Fire Sense
- Mr. Heater
- Westland
- Classic Accessories
- Koolatron Corp
- Howard Berger

Shop Appliances, A/C's & Heaters by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$117.69 Off
Infrared Heater
$4.00 Off
12-Volt Quick Cup Coffee Maker
$50.02 Off
Large Portable Ice Maker
Shop More Awnings, Canopies & Shade

- RV Awnings
- Awning Accessories
- Canopies & Shade
- Awning Rooms
- Home Awnings

View All Awnings, Canopies & Shade Products

Shop Our Top Brands

- Lippert Components Inc
- Dometic
- Carefree of Colorado
- Shelterlogic
- Polymer
- Direcsource Ltd
- Sunflair Products
- Camco
- Fisherman Creations Inc
- Fanatic Lights Llc

Shop Awnings, Canopies & Shade by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$75.90 Off
Multicolor LED Light Strip Kit
$37.83 Off
SideBlocker by Carefree - Black
$6.03 Off
Awning De-Flapper MAX
Shop More Bikes, Bike Racks & Carriers

- Bike Accessories
- Bikes
- Motorcycle
- Scooters & Accessories

View All Bikes, Bike Racks & Carriers Products

Shop Our Top Brands

- ADCO
- Swagman
- Bell Sports
- Heininger
- Inno Advanced Car Racks
- Classic Accessories
- Fast Master
- Lets Go Aero
- Cycle Force
- Maxx Group Llc

Shop Bikes, Bike Racks & Carriers by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$25.00 Off
XC Hitch or Bumper Mount Rack
$19.73 Off
RV Deluxe Bike Cover
$10.02 Off
Stromberg Ultra Bike Rack
Shop More Directories & Memberships

- Directories & Books
- Magazines
- Memberships

View All Directories & Memberships Products

Shop Our Top Brands

- Rv Education 101
- CQ

Shop Directories & Memberships by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$4.50 Off
Passport America - 1 Year
$2.00 Off
Rand McNally 2016 Road Atlas
$3.82 Off
Half Crocked Cookbook
Shop More Camping & Tailgating

- Bags & Packs
- Camp Cooking
- Camping & Tailgating Gear
- Clothing
- Emergency Preparedness
- Equipment Care
- Footwear
- Games & Toys
- Insect Repellants & Accs
- Instruments & Optics
- Knives & Tools
- Lights
- NASCAR
- Paddlesports

- Sleeping Bags, Cots & Air Beds
- Tents
- Travel

View All Camping & Tailgating Products

Shop Our Top Brands

- Coleman
- Direct Impulse
- Shelterlogic
- Life is Good
- Logo Chairs Co
- American Recreational
- Camp Chef
- Icon Eyewear
- Alps Mountaineering
- Household

Shop Camping & Tailgating by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$27.86 Off
Campfire Griddle Grill
$2.20 Off
Clip Lite
$5.02 Off
Class A Die-Cast Motorhome
Shop More Chairs, Recliners & Patio Mats

- Chairs
- Patio Mats & Rugs
- Patio Sets
- Tables

View All Chairs, Recliners & Patio Mats Products

Shop Our Top Brands

- Prest-O-Fit
- Picnic Time
- Kijaro
- Direcsource Ltd
- Byer Manufacturing Company
- Husky
- Travel Chair Company
- Adams
- Jamberly
- Caravan Canopy

Shop Chairs, Recliners & Patio Mats by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$14.30 Off
Zero Gravity Recliner, Black - 2 Pack
$10.00 Off
Reversible Greek Motif Patio Mat 6' x 9' - Coffee Brown
$5.00 Off
3' Fold N Half Aluminum Table
Shop More Covers & Storage

- Cargo Carriers & Slideouts
- Covers
- Garages & Car Canopies

View All Covers & Storage Products

Shop Our Top Brands

- ADCO
- Classic Accessories
- Elements Covers
- Shelterlogic
- RV Toy Store
- Camco
- Rightline Gear
- Great Day
- Stromberg Carlson
- Lets Go Aero

Shop Covers & Storage by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$264.78 Off
ADCO All Climate + Wind Designer Tyvek RV Cover - Class A, 34' - 37'
$174.35 Off
ADCO All Climate + Wind Designer Tyvek RV Cover - Travel Trailer, 18'1" - 20'
$211.31 Off
Classic Accessories PermaPro Heavy Duty RV Cover for 32' to 35' Class C RVs
Shop More Generators & Electrical

- Lighting
- Generators
- Power Protection
- Solar
- 12 Volt Power
- Batteries & Accessories
- Power Converters
- Power Inverters
- Power Cords

View All Generators & Electrical Products

Shop Our Top Brands

- Diamond
- ITC
- Husky
- Marinco
- Osram Sylvania Inc
- AP
- Camco
- RDK Products
- Uriah Products Llc
- TRC

Shop Generators & Electrical by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$25.47 Off
LED Replacement Bulbs - G4/JC10, 6 Pack
$49.50 Off
Portable 50-amp Surge Protector with Voltage Protection
$5.00 Off
Honda Generator Theft Deterrent Bracket
Shop More Electronics, GPS & Satellites

- Satellites & Receivers
- GPS & Navigation
- Antennas
- TVs & Accessories
- Thermometers
- Portable Audio
- Mobile Accessories
- Radios

View All Electronics, GPS & Satellites Products

Shop Our Top Brands

- Roadpro
- Winegard
- Audiovox
- La Crosse
- Axess Products Corp
- Dpi Inc
- ASA Electronics
- Mobile Communiations Inc
- TireMinder
- Magellan

Shop Electronics, GPS & Satellites by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$152.00 Off
Carryout Anser Portable Satellite Antenna
$30.02 Off
KING Digital HDTV Antenna System - White
$11.03 Off
Master Mount Locking Cantilever Mount, Small
Shop More Grills & Picnic

- Grills & Accessories
- Picnic

View All Grills & Picnic Products

Shop Our Top Brands

- Picnic Time
- Coleman
- Magma
- Direcsource Ltd
- Char-Broil
- Mr Bar-B-Q
- Weber
- Camp Chef
- Noetic Inc
- Camco

Shop Grills & Picnic by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$5.00 Off
Table Cover and Pads
$20.16 Off
Collapsible Ice Buckets - Orange
$2.14 Off
Rainbow Flame Sticks
Shop More Hardware, Roof Vents & Fans

- Doors & Window Screens
- Fans & Vents
- Propane & Accessories
- RV Cleaners & Supplies
- RV Replacement Hardware
- RV Roof Maintenance & Repair
- RV Storage & Maintenance

View All Hardware, Roof Vents & Fans Products

Shop Our Top Brands

- RV Designer
- Camco
- Thetford
- Trico
- Icon Technologies
- Perrycraft Inc
- Trusty
- Keystone Automotive Operations
- Mr. Heater
- AP

Shop Hardware, Roof Vents & Fans by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$1.00 Off
Rounded Baggage Door Catch - White
$3.30 Off
Unbreakable Polycarbonate Vent Lid - Fits Ventline, Elixir Since 1994
$3.51 Off
Baggage Door Latch - Fleetwood Style
Shop More Outdoor Living

- ATV & UTV
- Boats
- Fire Pits & Patio Heaters
- Garden & Patio Accessories
- Motorcycle
- Patio Decorations
- RV Auto Accessories
- Steps & Ladders
- Tools & Garage

View All Outdoor Living Products

Shop Our Top Brands

- Icon Technologies
- Classic Accessories
- Two Group Flag
- Good Directions
- Direcsource Ltd
- Great Day
- ADCO
- Fire Sense
- Polymer
- Stromberg Carlson

Shop Outdoor Living by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$15.62 Off
Aluminum Folding Step
$24.62 Off
2-Height Platform Step
$87.11 Off
Econo Porch 3-Step
Shop More Indoor Living

- Bath & Laundry
- Bedroom
- Kitchen
- Living Space

View All Indoor Living Products

Shop Our Top Brands

- Household
- Lippert Components Inc
- Interdesign
- Progressive International
- RV Designer
- Maxi-Matic
- Tervis
- Spectrum Diversified Designs
- Mattress Safe
- Direcsource Ltd

Shop Indoor Living by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$0.80 Off
Oak Cupboard Bar, 3-pack - 16" to 28"
$3.92 Off
Boot Tray
$5.44 Off
Garbage Bag Holder
Shop More Pet, Training & Feeders

- Pet Supplies
- Pet Training & Control
- Pet Bowls, Feeders & Storage
- Pet Beds & Carriers
- Pet Toys & Games

View All Pet, Training & Feeders Products

Shop Our Top Brands

- Gen 7 Inc Dba Gen 7 Pets
- Kurgo
- Primetime Petz
- Heininger
- Sure Fit
- Petego Egr Llc
- Radio Systems
- Classic Accessories
- PetEdge
- Direcsource Ltd

Shop Pet, Training & Feeders by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$1.00 Off
Water Hole Pet Dish
$1.00 Off
Flying Chicken Dog Toy
$39.99 Off
Gen7Pets Natural-Step Ramp for Pets
Shop More Sewer, Fresh Water & Cleaners

- Black Water
- Faucets & Shower
- Fresh Water
- RV Cleaners & Supplies
- Sewer Chemicals
- Sewer Connection
- Toilets

View All Sewer, Fresh Water & Cleaners Products

Shop Our Top Brands

- Valterra
- Thetford
- Camco
- Icon Technologies
- Dometic
- Eccotemp
- Lippert Components Inc
- Carrand
- Husky
- Prest-O-Fit

Shop Sewer, Fresh Water & Cleaners by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$9.46 Off
360 Siphon RV Vent Cap, White
$30.56 Off
SeaLand Toilet Water Valve Kit
$10.99 Off
Boiler -100ºF Antifreeze, Gallon
Shop More Towing, Levels & Chocks

- 5th Wheel Towing
- Car Towing
- Trailer Towing
- Mirrors & Backup Systems
- Jacks & Leveling
- Wheels & Tire Accessories
- Hitching & Towing
- Shocks & Stabilizers
- Truck Accessories
- Engine & Fuel Performance

View All Towing, Levels & Chocks Products

Shop Our Top Brands

- United Safety Apparatus
- Roadmaster
- Cequent
- Stromberg Carlson
- Ultra-Fab
- Husky
- Blue Ox
- Classic Accessories
- Elements Covers
- Progress

Shop Towing, Levels & Chocks by

- On Sale
- Internet Specials
- Free Shipping
- Best Rated
- New Products
- Clearance

Best Sellers

$1.65 Off
12" Lube Plate
$15.36 Off
Aluminum Stack Jacks, set of 4
$1.50 Off
Lock-N-Stop Chock

Click to enlarge, hover over image to zoom

# Honda EU2000i Generator - CARB Compliant

(35 Reviews) Add A Review
Catalog Item # 34961
This Item is In-Stock and Ready to Ship
Internet SALE
$899.00 SAVE $250.95

Reg $1,149.95

Quantity:
X
JUST ADDED TO YOUR CART
Have A Question About This Product?
42 Questions | 42 Answers
Read All Q&A | Ask a Question | Answer a Question

- More Images
- Videos

#### Like this product?
Share it!

Description

Quiet, lightweight Honda Portable Generators deliver clean, reliable power for camping, tailgating or a home power outage.
Exclusive Honda inverter technology produces steady power to run electronics and appliances and to charge automotive-type batteries. All feature fuel-efficient 4-stroke air-cooled overhead valve engines, recoil auto start and spark arrester/muffler.

- 2000 watts AC; 96 watts DC
- Power for computers and most kitchen appliances
- Runs 4 hours at 1600 watts rated load
- Connect two for 4000 watts of portable power
- Sound level: 59 dB at rated load
- Our Stores Service What We Sell!

  Note: This is a carb compliant model. For the non-carb compliant model, click here.

  Camping World is an authorized Honda dealer.

This item qualifies for Product Protection coverage! Protect Your Generator! Product Protection eliminates out-of-pocket expenses and protects against costly product repairs or replacement. We’ll cover 100% parts and labor for up to two years following the expiration of your manufacturer’s warranty. Warranty service is available at any Camping World SuperCenter.

Technical Specs

Tech Specs

Weight: 50.8 lbs.

Documents:
Owners Manual

Warranty: Manufacturer's 3-Year Warranty.

Manufacturer: American Honda

Mfg Part #: 659820

Tech Notes: At only 46.3 lbs, the EU2000i utilizes Honda's "state of the art" inverter technology to provide 2000 watts of lightweight, quiet and efficient power. This generator will run up to 15 hours on a single tank of gas when used with the Eco-Throttle feature. This easy starting generator produces only 45.9dB of sound at 7 meters with a full load, which is less than the rating of common speech. The Honda Inverter Technology makes this generator ideally suited for use with sensitive electronics (e.g., computer, fax, printer, and telephone, stereo) because the generator produces a clean sine wave of energy that prevents surging. To prevent any possible damage to the unit, the Oil Alert will shut the unit off when the oil drops below a safe operating level. The unit also has a DC terminal for use when charging 12-volt automotive type batteries. The available power is commonly used for the following typical electric devices:

- Full Size Microwave Ovens
- Larger Power Tools i.e. circular saw
- Resistive Load Kitchen Appliances (i.e. Coffee Maker, Toaster, small a/c units etc).
  Two like EU series generators can be linked in parallel to increase available wattage through the generator outlets.

  Engine | Honda GX100
  Displacement | 98.5 cc
  AC Output | 120V 2000W max.(16.7A) 1600W rated (13.3A)
  Receptacles | 20A 125V Duplex NEMA Plug Number: 5-20P
  DC Output | 12V, 96W (8A)
  Starting System | Recoil
  Fuel Tank Capacity | 1.1 gallons
  Run Time on One Tankful | 4 hrs. @ rated load 9.6 hrs. @ 1/4 load
  Dimensions (L x W x H) | 20.1" x 11.4" x 16.7"
  Noise Level | 59 dB @ rated load 53 dB @ 1/4 load
  Dry Weight | 46.3 lbs.

Related Items

Items Selected: (0)
Add Selected Items to Cart

Reviews

Add A Review

Honda EU2000i Generator - CARB Compliant: Customer Reviews

Camper's Choice Rating

(5 Based on 35 Reviews)

Pros
Durable (1)
Easy to Store (1)
Easy to Use (1)
Exceeded Expectations (1)
Light Weight (1)
Cons
Too short of run time (1)

Reviewed by 35 customers

By SIH
from Lompoc, CA

# Generators were recommended by salesman

0 out of 0 people found this review helpful.
September 12, 2015
We bought two generators, at the recommendation of our salesman. First of all, the run time is way too short. We explained to the salesman that we will be living in this RV for several months to a year or more. We had to get up in the middle of the night to add more gas to keep the a/c running. Second, the salesman said two generators would handle running the a/c and the other appliances at the same time. They do not! We tested them twice. We ran the a/c and a vacuum cleaner and the a/c and the washer/dryer combo unit. The generators kicked off within a couple of minutes. The second test was the a/c and the washer/dryer combo unit. We had to turn off the a/c, exit the RV while the laundry finished. During both test periods, there were no lights or anything else running. We wanted to return them for a unit that would handle everything. Now we have to buy another unit to handle running more appliances and with a longer run time. Also, we didn't know we could not run these in the storage compartment. We have to build an insulated box with ventilation and security to run these outside. Very disappointed with Camping World! This was our very first RV purchase, as we told the salesman, so we relied on his "expertise" because we had no clue.... That was our first mistake. Recommendation: Do your homework! You can't rely on salespeople to give you the best advice.
Pros: Quiet, Easy to Use, Easy to Store
Cons: Too short of run time
Was this review helpful? Yes / No
By Charlie Nixon
from Green River, WY

# Generator

0 out of 0 people found this review helpful.
September 05, 2015
Best generator that I have bought, out of three, the first two were loud, heavy, low quality, & hard to store. Honda is quiet, dependable, easy to store under the front end of my fifth wheel, never has failed to start even when it runs out of fuel. Choke full, first pull, & on the second it fires right up. I would recommend this unit to any and all who need a generator. Simply the best buy I've ever made & will soon consider the mate for it to run air conditioner, with them. We have owned it for now the forth year.
Pros: Quiet, Light Weight, Exceeded Expectations, Durable
Was this review helpful? Yes / No
By KEN G
from LOS ALTOS, CA

# Nothing beats a Honda

0 out of 0 people found this review helpful.
March 13, 2015
I did a lot of research before buying this generator and the companion. We made the purchase just before Christmas and have used both of them about a half dozen times on camping trips. They are extremely quiet and will run on a tank of gas nearly all day. I leave them sitting in the bed of my truck and from the front of the truck, you can't hear them running unless they go to full speed (which is very seldom). Yes, they are a little more than the others, but should last for many years.
Was this review helpful? Yes / No
By Alex Mendoza
from Rancho Cucamonga, CA

# Honda Gen EU2000i

0 out of 0 people found this review helpful.
August 01, 2014
I bought this after going camping and not having any type of current to use. This generator is quiet and very easy to use. I carry it in my truck and when I use it sometimes I leave it in the truck bed, it's that quiet to use. It will handle almost everything but not the air conditioner which that's okay. Lightweight and I also bought the bag with rollers and the locking handle for security.
Was this review helpful? Yes / No
By BM
from Surrey, BC

# Unbelievable Performance - a must for RV'ing

0 out of 0 people found this review helpful.
April 24, 2014
I have both the EU2000i and companion - bought them last year. They both start on the 2nd pull. I run both for a/c use with other appliances running and they run flawlessly. They are quiet. Very fuel efficient and powerful. I dropped $2grand at Camping World in Burlington WA and was money very well spent. Non-electric site? - no problem. 90degree heat? - just plug them in and let the a/c run. Well done Honda.
Was this review helpful? Yes / No
By Anonymous

# Great generator

0 out of 0 people found this review helpful.
December 15, 2013
Quiet and does what is advertised.
Was this review helpful? Yes / No
By Shelly May
from Wake, VA

# Life Saver

0 out of 0 people found this review helpful.
November 20, 2013
Ok so we get to where we are dry camping with no power and running water. I think I am all ready, but bought this generator just in case. Well the refrigerator goes and the only way the outside one will work is with electricity. We moved all the food to the outside set up the generator and vacation saved. We could have put everything in coolers but what a mess and hassle. This is so easy to start runs very quietly!!
Was this review helpful? Yes / No
By Walter
from New Smyrna Beach, FL

# Honda Gen

0 out of 0 people found this review helpful.
May 10, 2013
This is an excellent product, easy start on second pull, economical on fuel, and quiet. We use it with our camper.
Was this review helpful? Yes / No
By Carl Jonson
from Maricopa, AZ

# Great Generator

0 out of 0 people found this review helpful.
April 11, 2013
Honda makes good stuff. I will buy the second unit for the full 30 amps. These are easy to move around and super quit. All the Honda equipment that I have bought over the years have been well worth the investment. They make the best snow thorougher on the market. Carl from AZ. / Wyoming
Was this review helpful? Yes / No
By Anonymous

# Generator

0 out of 0 people found this review helpful.
April 04, 2013
Received as promised.
Was this review helpful? Yes / No
By Ray Stanton
from scappoose, OR

# this is a sale

0 out of 0 people found this review helpful.
March 08, 2013
this is no sale 999.99 is what you want in the store every day!!! I was just there!!
Was this review helpful? Yes / No
By Anonymous

# EU200i review

0 out of 0 people found this review helpful.
December 26, 2012
Very pleased with the Honda generator I purchased. It was easy to get into operation and was very quiet.
Was this review helpful? Yes / No
By Lance Rogers
from Calgary, AB

# Wow!

0 out of 0 people found this review helpful.
December 03, 2012
Considering I had a Honeywell 2000i for several years, I think I know a good generator when I see one. (Let's be honest, the Honeywell is hard to start and noisy as all get out, but it did work) Put in some oil and some gas into the Honda and she started right up on the first pull. What can I say, I love my Honda 2000i!!!
Was this review helpful? Yes / No
By Paul O.
from Gardiner, ME

# Nice Generator

0 out of 0 people found this review helpful.
November 10, 2012
I've had one of these for about six months now. It runs everything in the RV except the AC unit, it'll even run an electric oil filled radiator w/o breaking a sweat. I almost bought the Yamaha equivalent because of the fuel shut off. Well I left gas in it for about two months and the carb gummed up and had to be cleaned as there is no fuel line shut off like the Yamaha. I bought this because I got a better deal on the Honda than the Yamaha. Do not get me wrong this little generator is awesome just be aware of how long you leave gas sitting in the carb. Note: I just found a drain valve on the bottom of the bowl on the carb for draining, hopefully I'll never leave gs sitting again.
Was this review helpful? Yes / No
By Kansas Camper
from Benton, KS

# Reliable and quiet

0 out of 0 people found this review helpful.
October 23, 2012
I purchased a Honda EU2000i generator in spring of 2002 for dry camping. At remote campsites I sometimes use multiple extension cords to place it about 100 feet away from the trailer, which makes it inaudible inside the trailer and barely noticeable sitting outside. It does a nice job keeping batteries charged, and running the microwave. I usually run it about 3 or 4 hours daily, using maybe 1/2 gallon per day. It gets about 50 to 70 hours of use per season, at elevations of up to 11,000 feet in Colorado. It usually starts on the first or second pull, even after 6 months of disuse during the winter. The only maintenance have been annual oil changes. After 11 seasons it finally developed a carburetor problem, will only run (at reduced power) with the choke partially closed, probably a partly blocked jet. I will take it in for service in a few days. I never expected to get 11 seasons of use without repairs when I bought the unit.
Was this review helpful? Yes / No
By Anonymous

# Absolute GREAT inverters &amp; runs my RV's 15k BTU AC with no problem!

0 out of 0 people found this review helpful.
September 26, 2012
I purchased this generator and the Honda EU2000i CARB Compliant Companion generator. This combo of the two 2000's is great.. They handle &store away in the RV compartments. They start and power the 15k BTU AC & other items.
Was this review helpful? Yes / No
By Floyd MacDougall
from L'orignal, ON

# Honda eu2000i genertor-carb compliant

0 out of 0 people found this review helpful.
August 28, 2012
Great product,shipping charges should be free for canadian customers also ,we would purchase more products, plus duty fees makes savings less interesting;
Was this review helpful? Yes / No
By Mike McClure
from Berry Mills, NB

# Best generator For Small Needs

0 out of 0 people found this review helpful.
August 28, 2012
I have two of these generators and can not say enough good about them. Quiet, Light, Good on fuel, and very Reliable
Was this review helpful? Yes / No
By Rodney Englewood, FL
from Englewood, FL

# Honda EU2000i Generator

0 out of 0 people found this review helpful.
August 28, 2012
I purchased this generator as a fuel efficient generator to charge the batteries on my MH rather then running the 5KV Gen. I was able to move the Honda away from the RV so there was NO NOISE and it runs for hours on a gallon of gas. I am very pleased with this unit and would recommend it to my friends. Always starts on the first pull even over 9’000 ft. :)
Was this review helpful? Yes / No
By Richard Sullivan
from EL DORADO HILLS, CA

# CARB Compliant ?

0 out of 0 people found this review helpful.
June 17, 2012
This is an outstanding generator! It runs my microwave oven and the roof A/C on my Lance Cab over camper. (not at the same time) It is quiet, well made and easy to move around. My issue was the price compaired to cheeper generators that the California Air Recources Board (CARB) wont let me buy in CA. Just when I was off to Nevada to get a CARB non-approved generator, I ran out of time and went into my local Camping World and bit the bullit. No regrets, this thing rocks! I hear CARB is about to out law Bean Burritos to reduce emissions... but the service at Camping World and the quality of this gen make over regulation / over taxation (California) a little easer to take!
Was this review helpful? Yes / No
By Jim Saito
from Fremont, CA

# Quality product

0 out of 0 people found this review helpful.
June 12, 2012
The Honda generator performs exactly as advertised . Great gas consumption, good power , quiet , and compact . Great for camping , especially for recharging my two Bass boats trolling motor batteries . Delivery was less than a week from camping world , good service .
Was this review helpful? Yes / No
By Brenda
from Tracy, CA

# Great generator!

0 out of 0 people found this review helpful.
June 05, 2012
A great little generator. It even started up my Trailmanor AC unit and kept it going. Quiet and portable. Perfect for camping!
Was this review helpful? Yes / No
By James Donaldson
from Oviedo, FL

# Honda EU2000i with Parallel kit

0 out of 0 people found this review helpful.
May 11, 2010
I purchased these two generators with the belief I could run my single RV AC which is rated 15000 BTU at 3000 watts. (They are supposed to handle 4000 watts easily) First, one would not work and it took me many trips to a Honda repair shop and several emails to the national service center before some local guy (not Honda) told me the problem was probably just the vacum valve on the cap. He was right. It was just set in the wrong position. So after a year of frustration, I finally got them both to work. Then I found out that they will not carry the load as advertised. When I turn on the AC it kills them both. So the bottom line is I really needed this to work and went with Honda because the seemed the best buy. Not so. I also told my local Camping World about the problems hoping to help someone else, but because I did not buy them there they were not interested. I paid out over $300.00 in service calls that did not fix the problem. The reason I had to pay was "They could not find a problem".
Was this review helpful? Yes / No
By Joe Hall
from New Albany, MS

# ran great

0 out of 0 people found this review helpful.
December 18, 2009
Hi this eu2000i has ran great with no problems up to 6050 hours. At 6060 hours it worn out the cam shaft-16.00 dollar part and the 17.00 dollar timing belt..Also the oil sensor I think need replaced it was giving me problems when it was real cold out side ( at the end).I used mobile 1 syn oil in it. And only change the spark plug twice. Now sure if we are going to buy another eu2000 are a yahama ef2000. I guess if I had checked the valves I would have seen this coming But im going to try to get the old eu2000 back up and running it was running when it took it apart
Was this review helpful? Yes / No
By Anonymous

# desert camping

0 out of 0 people found this review helpful.
September 03, 2009
I have two Honda EU2000i generators with the parallel power kit that I take camping with my pop-up camper. They run the AC on the pop-up camper, recharge the batteries and keep me with the comforts of home when I am in the desert. When I go camping, I go dry camping in the middle of nowhere. These small, quiet generators are wonderful.
Was this review helpful? Yes / No
By Brian S.
from VISALIA , CA

# Great Generator

0 out of 0 people found this review helpful.
July 29, 2009
I take my EU2000 to the desert and run a DLP projector, DVD setup, 40 watt amp with surround sound through a PA and show first run movies on the side of my trailer with a 10 ft screen. Also pop the popcorn ALL AT THE SAME TIME. This is an awesome generator and portability is the key. You can't beat the Honda for quiet running. I love this thing.
Was this review helpful? Yes / No
By Anonymous

# Ref. short run time and shut downs reported

0 out of 0 people found this review helpful.
July 17, 2009
I have a new 2000 I unit and have run it for about two months to keep up the batteries and AC unit on a Police vessel while doing Port Security. I found it works very well but, has a very small carburetor bowl and is very subject to contamination in fuel added to the gen set. As to the problem reported about short run time…I have located a company “on line” that had a replacement cap and fuel system using a boat fuel 5 or 6 gallon tank. It is a great system and the folks have a “Y” connection set up for two gen sets off the same external tank. That should run the two generators all night without the flashlight in the mouth trick. Now that I know about the fuel problems and what to look for with water etc., I would give the Honda Generator a big thumbs up.
Was this review helpful? Yes / No
By gadget guy
from san marcos, CA

# gadget guy

0 out of 0 people found this review helpful.
June 12, 2009
This generator has a video manual available online at www.handbooklive.com under tools category. I watched the video and it shows how to use this generator step by step. Very helpful, so for me it was a no brainer on my purchase decision. I can now perform all the basic maintenance myself, and keep my generator running its best. Easy first pull every time I start this thing , super reliable, I am a happy camper with this one.
Was this review helpful? Yes / No
By Anonymous

# helpfull

0 out of 0 people found this review helpful.
April 05, 2009
JD of FL take your two gen. hook up together at your dealer under load as if you where when it failed for you ! if that not posible get dealer to come to your location to show him ! but you might first try a new gas cap get dealer to lend you one to try sound like starving for gas? honda needs to make bracket so you can lock these gen. up handle about only spot to hook onto as of now and that don't sound too good any more. so I put mine away at night or not going to be around out of sight out of mind but works fine so far had a old style 1000 for years new 2000 does so much more good luck JD
Was this review helpful? Yes / No
By Lawrence H.
from Vancouver, WA

# Works perfectly within scope of ability

0 out of 0 people found this review helpful.
April 03, 2009
I've owned an Eu2000 for five years or more. Mine has worked flawlessly during that time and it has lots of hours of running time charging my boat's batteries and use during power outages. It gets its oil and spark plug changed every year and the air filter cleaned. We like it at the docks because it is quiet. We understand that ratings for generators are always on the high side, to allow for extra start-up draws of electrical appliances, which sometimes can be double the appliance's ratings, until they settle down. I have had no problem running a large 1500 watt microwave oven with start up at 2200 watts or more. Even running our full size refrigerator (new) and freezer (old) at the same time during power outages is no problem for my 2000. One has to add up the wattage of the appliances they are using and then add about 25% to allow for start up draw, Turning on appliances one at a time after the gen has warmed up helps too. Two EU2000 Gens are going to give you about 3000 continuous use watts....not 4000. It's a numbers game that all genset companies play. If one truly need 4000 watts, one should get a 6000 watt gen so it isn't running full speed all the time. If one uses their genset within these guidelines, no matter what brand, it should perform well for years. I prefer the honda because of the weight to noise to power ratios. A two cycle engine would be lighter and less expensive, but they are inherently more noisy and smokey because of adding oil to the fuel. Over all, Honda's engineering is second to none going back to the early 60s, when they first introduced the 50cc motorbike to the USA, many of which are still running. If my Honda genset ever wears out, I will definitely get another Honda.
Was this review helpful? Yes / No
By orlando pacheco
from bronx, NY

# honda eu 2000 generator-carb-compliant

0 out of 0 people found this review helpful.
November 13, 2008
honda
Was this review helpful? Yes / No
By melissa evans
from grottoes, VA

# handle problems

0 out of 0 people found this review helpful.
October 21, 2008
we loved our eu2000i generator until we discovered that the handle had been busted with a blunt object and it was stolen. it was chained thru the handle the chain was untouched. i think honda needs to prevent theft on the eu2000i by inserting some kind of steel bar inside the plastic handle. other than that it did an awesome job. instead of another eu2000i i purchased another honda generator and got the eu3000 because i liked the fact that it is a little more difficult for thief to take it. can't wait to use it.
Was this review helpful? Yes / No
By Steve Bernard
from RANCHO CORDOVA , CA

# Dry camping money saver

0 out of 0 people found this review helpful.
October 11, 2008
We camp where there is no electric hookup, so running the noisy rv generator uses .9 gal/hr and our Honda 2000i only uses .25 gal/hr. Great savings on gas if we don't have to use the rv genny for a/c purposes. We put the Honda 100 feet from the rv and connect with an extension cord so we can't hear the Honda at all and it runs everything but the a/c units! What a decibel difference and fuel savings.
Was this review helpful? Yes / No
By Tom Hazlett
from Prairieville, LA

# More You Need To Know

0 out of 0 people found this review helpful.
September 08, 2008
Bought 2 of the EU2000 units I with the paralell kit for use with my 5th wheel trailer. Though specs are specific about 4 hr run time at full load, I did not realize that running just my 15K A/C unit would give me only 5 hr of run time. Found it hard to get up at 3 AM to refill units with gas while holding flashlight in my teeth to try not to overfill the gas tanks. All other elements of units are top of the line but doubt I would have bought units had I realized this shortcoming.
Was this review helpful? Yes / No
By Anonymous

# Best set of generators for RVing.

266 out of 305 people found this review helpful.
June 14, 2008
Bought two Honda EU2000i's and the parallel kit. Both generators are able to power my 15,000 BTU air conditioner in the travel trailer. Additionally, I'm able to keep the television running, the fridge and some lights if need be. When it's not hot enough for the air conditioner, we just bring one Honda generator on camping trips. One powers up pretty much everything and charges the trailer batteries during the day time. These generators are expensive, but you get what you pay for. Light weight, quiet operation and plenty of power when running parallel. Worth every penny.
Was this review helpful? Yes / No

Q & A

## Product Question & Answer

42 questions : 42 answers
Expand All
What does carb compliant mean?
1 answer(s)
by Anonymous November 26, 2015
CARB is short for 'California Air Resource Board'. California has additional air pollution standards beyond EPA regulations. California ARB
December 01, 2015
How much does it weigh?
1 answer(s)
by Anonymous November 25, 2015
Dry weight is 46.3 lbs.
November 25, 2015
Is this the discontinued model?
1 answer(s)
I know Honda discontinued some models. Is this EU2000i Model discontinued?
by jimmuy November 18, 2015
No, this is not a discontinued model generator. If anything, most generator manufacturers discontinued their 49-state variations(we had both a 49 state and CARB model EU2000i at one time) and just fabricate a CARB compliant model so it can be sold/used in all 50 states.
November 24, 2015
What is the oil change, maintenance time?
1 answer(s)
by gliders November 16, 2015
The oil in this generator is to be changed after the first month or 20 hours of operation. After that, every 6 months or 100 hours of operation.
November 19, 2015
What is the difference between the EU2000i and the EU2000iA
1 answer(s)
We are looking for a 30 amp generator and don't know which one to get. Don't plan on tethering right now but want the capability to do so later. Thank you
by mollymae November 11, 2015
While the power capability is the same between an EU2000i and EU2000iA. The EU2000i model has two 20amp 125volt AC duplex receptacles(like you see at home) and a special 12volt DC receptacle for Honda's battery charging cable. The EU2000iA is the Companion variation that has one 20amp 125volt AC receptacle and a 30amp 125volt AC locking receptacle(L5-30R) that allows the use of a adapter like SKU#69591 to connect to an RV 30amp cordset.
November 20, 2015
Can parallel cable kit connection cables attach to any two same type of honda generator example two Honda EU2000i
1 answer(s)
by Buddie November 11, 2015
If the generator has parallel ports and is a compatible model, yes. Not all Honda generators have parallel capability, but the EU2000i does have parallel capability with a matching EU2000i or EU2000iA generator. Double your power with parallel capability by Honda Power Equipment
November 20, 2015
Will this run an 8000btu portable air conditioner?
1 answer(s)
by Anonymous September 24, 2015
Yes, It should run it without any issue.
September 25, 2015
How to plug in
1 answer(s)
So, if I have this, and buy the adapter to go from 30 to 120, I should be able to power most everything in the trailer with the exception of a/c? Thanks!
by Kim Van August 17, 2015
Yes, you can use an adapter like item# 69604 to connect a 30amp RV power cord to the generator which should power a number of appliances besides an A/C. For priority appliances that require power, you will want to find the wattage for to ensure the generator can run them.
August 17, 2015
Can this support running AC unit?
1 answer(s)
by Anonymous August 01, 2015
A 9,200 BTU rooftop unit can likely run off a 2000 watt generator, possibly an 11,500 BTU unit. The power requirements would have to be double checked. A majority of 13,500 BTU units or larger require a minimum of a 3000 watt generator to operate.
November 16, 2015
How much is the parallel cable?
1 answer(s)
does buying the eu2000i and a second unit for parallel extra power are the same unit? Also is there a 220v plug or what is the plug size and config for the parrallel increased power? the weeght of each unit is?
by JC July 22, 2015
Parallel cables are available as cable only, item# 25929, or cable plus 30amp RV adapter, item# 63712. Like model generators must be used for the parallel feature to work. Explanation on how it works and the configuration options can be viewed at Honda's parallel page.

No, there is not a 220V plug available, if 220V AC service is needed, you will have to upgrade to an EM/EB/EG 4000 model or larger generator. If trying to connect this generator to an RV with 50amp style cord, either a special pigtail will have to be located to go from generator 3 prong locking plug to RV 50amp or use an additional adapter/pigtail to go from 30amp RV to 50amp RV when item# 63712 is used.

Weight of the EU2000i and EU2000i Companion is 46 lbs.
July 24, 2015

What is the companion spoken of needed to run AC?
1 answer(s)
by Anonymous July 19, 2015
The Honda EU2000i Companion model is listed as item# 43844.
July 20, 2015
Do I have to buy an adapter to be able to plug in my 5th wheel plug?
1 answer(s)
I'm new to the generator/5th wheel, and don't understand how the 2 110v plugs can allow the bigger plug that goes into the 5th wheel. I basically want to charge the batteries that are in the 5th wheel, and also use an electric coffee maker.
by Anonymous July 10, 2015
Yes, an adapter will have to be purchased to connect an RV to a portable generator. Use item# 69604 to go from the 120V duplex to 30amp RV. If your 5th wheel has a 50amp electrical cable, an additional pigtail will have to be used item# 69613. For battery charging and minimal appliance use, a generator of this size is suitable. If you would like to use one rooftop air conditioner, the generator will have to be upgraded to something like item# 48710 and use adapter item# 69591.
July 13, 2015
Warranty good outside us?
1 answer(s)
I live in canada. If I buy it in the us, can I get warranty work done in canada
by Anonymous July 10, 2015
No, Honda has territory sales and their power equipment sold accordingly especially the warranty.

We deal American Honda generators, the warranty can only be used in the United States, Puerto Rico, and U.S. Virgin Islands. Our Honda generators follow EPA and CARB standards and are not CSA approved, you will want to go to an approved Canadian dealer of Honda Power Equipment to obtain a CSA approved unit with Canada only warranty. Honda of Canada
July 10, 2015

Will it run a1300btu air conditioner
1 answer(s)
by Jay May 25, 2015
A 1,300 BTU air conditioner, yes because the watt and amp requirement would be so low. As for a 13,000 BTU air conditioner, no. Two EU2000i in parallel would be needed to provide the proper amount of watts/amps to start the air conditioner.
October 12, 2015
Does the EU2000i require an external ground?
1 answer(s)
by MarciB May 24, 2015
For the most part, no. NEC Article 250.34 "Generators-Portable and Vehicle-Mounted" have an exemption regarding this as well as OSHA 29 CFR 1926.404(f)(3)(i). Honda manufactures their generators with a ground terminal that is "connected to the frame of the generator, the metal non-current-carrying parts of the generator, and the ground terminals of each receptacle."

Before the use of an external ground is configured, consultation with local jurisdiction will be required as there are subset permissions/regulations on proper grounding.
October 08, 2015

Do you ship to Canada? What is difference between the 2,000i and the ik?
1 answer(s)
by Bill May 20, 2015
We do ship to Canada. However, Honda Generators cannot be delivered outside of the U.S. Honda Power Equipment engineers and manufacturers their generators for regional use. Please use the dealer locator here for a Canadian region dealer.
October 02, 2015
What outlet will run ac unit when paralleled?
1 answer(s)
I just purchased 2 eu2000i. with the parallel cord hooked up which ac outlet do I use to power my 13500 ac unit or does it matter?
by Anonymous May 04, 2015
You can plug into which ever outlet you want.
May 09, 2015
Can this run a flat panel tv?
1 answer(s)
by brad April 02, 2015
This is capable of up to 2000 watts, 16.7 amps. Compare this to the ratings of your television to know for sure.
April 02, 2015
What is the P/N for wheels for easy moving?
1 answer(s)
by Don November 12, 2014
See item 49403.
November 12, 2014
What decible is the noise level?
1 answer(s)
by Anonymous October 29, 2014
59dB at rated load, 53dB at 1/4 load.
October 29, 2014
Does the battery charging cable come in package
1 answer(s)
by Anonymous October 13, 2014
No, the charging cord is sold separately. See item 25928.
October 15, 2014
Do you ship to Canada?
1 answer(s)
by Wilnot13 July 23, 2014
Unfortunately, Honda generators cannot be shipped to Canada.
July 23, 2014
hi
1 answer(s)
ship to puerto rico?
by arturo May 02, 2014
Unfortunately, the Honda generators are unable to ship outside of the U. S.
May 05, 2014
what is the height of the 2000
1 answer(s)
by benthos April 13, 2014
Dimensions (L x W x H): 20.1" x 11.4" x 16.7".
April 15, 2014
Does it have electric start or just manual pull start?
1 answer(s)
by Murph February 17, 2014
This is pull start only.
February 17, 2014
Does the generator come with the DC battery charge cord?
1 answer(s)
by vike February 16, 2014
The charging cord is sold separately, see item 25928.
February 17, 2014
What is Carb Compliant ?
1 answer(s)
by Anonymous January 15, 2014
CARB Compliant refers to meeting criteria set by the California Air Resources Board for emissions control standards.
January 16, 2014
whats the size and length of the generator
1 answer(s)
by mitchel January 09, 2014
Here's the information you have requested: Dimensions (L x W x H) 20.1" x 11.4" x 16.7" and Dry Weight is 46.3 lbs.
January 09, 2014
Can a companion work in parallel with the standard EU2000i?
1 answer(s)
by Jj November 20, 2013
That is exactly what it is designed to do, however it will also work as a stand-alone unit.
November 20, 2013
If I put this in the generator compartment of my Eagle Cap truck camper, do I have to take it out of the compartment to use it?
1 answer(s)
If I don't have to take it out, do I have to open the compartment when it's in use?
by Anonymous September 22, 2013
These are designed for outdoor use, we recommend taking it out of the compartment before operating.
September 26, 2013
Can you run this on Propane?
1 answer(s)
by Mr Beecave May 19, 2013
No, use unleaded gasoline only.
May 21, 2013
What is the difference between this and a companion generator?
1 answer(s)
Can I put two of these together?
by sam April 14, 2013
The EU2000i is just the standard 2000 watt generator. The difference between it and the companion would be that it will not come with a 30 amp plug. You would have to buy an adapter. You can hook two of these up in parallel.
April 17, 2013
Refrigerator Startup?
1 answer(s)
My refrigerator draws 7 amps. Will my EU2000i start it up, since starting wattage is greater than running wattage?
by Don February 26, 2013
The EU2000i is capable of up to 2,000 watts at 16.7 amps, this should be more than sufficient for your refrigerator.
February 27, 2013
Hook up cable
1 answer(s)
Does the generator, ie 2000, come with the necessary cord to hook into a house or RV? Or is this an accessory that needs to be purchased?
by Homer February 11, 2013
Cords and adapators are sold separately.
February 14, 2013
Can this run at 13 amps AC and charge a battery at the same time?
1 answer(s)
by Bob February 05, 2013
The 12 volt charging feature will draw off of the available amperage, up to 8 amps in that channel.
February 05, 2013
Does the voltage double when linked?
1 answer(s)
by camper February 01, 2013
Not the voltage, no, hooking two of these in parallel will provide a higher amp availability and higher watts. The voltage remains 120.
February 03, 2013
Will the EU2000i power a small pop-up camper?
1 answer(s)
by Anonymous January 13, 2013
In most cases, yes, the EU2000I will power a small pop-up camper. (not intended for air conditioners)
January 14, 2013
What kind of fuel does this burn?
1 answer(s)
by lifircik January 06, 2013
This uses unleaded gasoline.
January 07, 2013
What is the warranty on this product?
1 answer(s)
by Raf December 19, 2012
The manufacturer's warranty is 3 years.
December 19, 2012
Can the companion model be used alone?
1 answer(s)
by Anonymous December 12, 2012
Yes, the two versions of the EU2000 model are usable independantly of one another.
December 12, 2012
Could I use this is in my house to run my refrigerator or freezer?
1 answer(s)
by Anonymous December 05, 2012
This generator can be used for home appliances, however the generator itself will need to be outside the house due to the exhaust.
December 08, 2012
Does this need Honda brand oil? Where do I get it?
1 answer(s)
by Anonymous December 05, 2012
It is recommended to use the Honda brand oil, yes. You can pick that up at any Camping World store or authorized Honda dealer.
December 08, 2012
Ask Your Question
x
Honda EU2000i Generator - CARB Compliant

Quiet, lightweight Honda Portable Generators deliver clean, reliable power for camping, tailgating or a home power outage.

### Enter Your Question:

Example: How many are in a package?
Add additional details (optional)
Have a question about customer service?
If you wish to share feedback with us about product selection, pricing, ordering, delivery or other customer service issues, please do not submit this feedback through the Question & Answer Service. Please contact Customer Service at 1-888-626-7576.

### Your Nickname:

Keep me anonymous

### Your E-Mail:

Your email address will ONLY be used to notify you regarding your question.
Need help? We're here for you
chat
email
phone
chat now
email now
Call 1-888-626-7576
X